@@ -28,7 +28,6 @@ class BottleParser(core.Parser):
         """Pull a querystring value from the request."""
         return core.get_value(req.query, name, arg.multiple)
 
-
     def parse_form(self, req, name, arg):
         """Pull a form value from the request."""
         return core.get_value(req.forms, name, arg.multiple)
@@ -38,7 +37,8 @@ class BottleParser(core.Parser):
         try:
             return core.get_value(req.json, name, arg.multiple)
         except (AttributeError, ValueError):
-            return None
+            pass
+        return core.Missing
 
     def parse_headers(self, req, name, arg):
         """Pull a value from the header data."""
