@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
+
 import sys
 import functools
 import inspect
@@ -8,9 +10,11 @@ PY2 = sys.version_info[0] == 2
 if not PY2:
     iteritems = lambda d: iter(d.items())
     unicode = str
+    text_type = str
 else:
     iteritems = lambda d: d.iteritems()
     unicode = unicode
+    text_type = unicode
 
 
 class WebargsError(Exception):
@@ -77,10 +81,12 @@ def noop(x):
 class Arg(object):
     """A request argument.
 
-    :param default: Default value for the argument. Used if the value is not found
-        on the request.
     :param type type\_: Value type. Will try to convert the passed in value to this
         type. If ``None``, no type conversion will be performed.
+    :param default: Default value for the argument. Used if the value is not found
+        on the request.
+    :param bool required: If ``True``, the :meth:`Parser.handle_error` method will be
+        invoked if this argument is missing from the request.
     :param callable validate: Callable (function or object with ``__call__`` method
         defined) used for custom validation. Returns whether or not the
         value is valid.
@@ -93,13 +99,16 @@ class Arg(object):
     :param bool allow_missing: If the argument is not found on the request,
         don't include it in the parsed arguments dictionary.
     :param str target: Where to pull the value off the request, e.g. ``'json'``.
+    :param str source: Key at which value is located, if different from key in
+        argmap
+    :param metadata: Extra arguments to be stored as metadata.
 
     .. versionchanged:: 0.5.0
         The ``use`` callable is called before type conversion.
     """
     def __init__(self, type_=None, default=None, required=False,
                  validate=None, use=None, multiple=False, error=None,
-                 allow_missing=False, target=None):
+                 allow_missing=False, target=None, source=None, **metadata):
         self.type = type_ or noop  # default to no type conversion
         if multiple and default is None:
             self.default = []
@@ -114,6 +123,8 @@ class Arg(object):
             raise ValueError('"required" and "allow_missing" cannot both be True.')
         self.allow_missing = allow_missing
         self.target = target
+        self.source = source
+        self.metadata = metadata
 
     def _validate(self, value):
         """Perform conversion and validation on ``value``."""
@@ -124,7 +135,7 @@ class Arg(object):
         except ValueError as error:
             raise ValidationError(self.error or error)
         # Then call validation function
-        if not self.validate(ret):
+        if self.validate(ret) is False:
             msg = u'Validator {0}({1}) is not True'.format(
                 self.validate.__name__, ret
             )
@@ -199,7 +210,7 @@ class Parser(object):
                 function = func
             else:
                 function = getattr(self, func)
-            value = function(req, name, argobj)
+            value = function(req, argobj.source or name, argobj)
         else:
             value = None
         return value
@@ -266,7 +277,7 @@ class Parser(object):
                         parsed_value = self.fallback(req, argname, argobj)
                     parsed[argname] = parsed_value
             if _callable(validate):
-                if not validate(parsed):
+                if validate(parsed) is False:
                     msg = u'Validator {0}({1}) is not True'.format(
                         validate.__name__, parsed
                     )
